==> dirac_0.5.4.orig.tar.gz: dirac-0.5.4/util/instrumentation/libdirac_instrument/motion_colour_arrows.h <==
/* ***** BEGIN LICENSE BLOCK *****
*
* $Id: motion_colour_arrows.h,v 1.2 2004/11/22 13:42:33 asuraparaju Exp $ $Name: Dirac_0_5_4 $
*
* Version: MPL 1.1/GPL 2.0/LGPL 2.1
*
* The contents of this file are subject to the Mozilla Public License
* Version 1.1 (the "License"); you may not use this file except in compliance
* with the License. You may obtain a copy of the License at
* http://www.mozilla.org/MPL/
*
* Software distributed under the License is distributed on an "AS IS" basis,
* WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
* the specific language governing rights and limitations under the License.
*
* The Original Code is BBC Research and Development code.
*
* The Initial Developer of the Original Code is the British Broadcasting
* Corporation.
* Portions created by the Initial Developer are Copyright (C) 2004.
* All Rights Reserved.
*
* Contributor(s): Chris Bowley (Original Author)
*
* Alternatively, the contents of this file may be used under the terms of
* the GNU General Public License Version 2 (the "GPL"), or the GNU Lesser
* Public License Version 2.1 (the "LGPL"), in which case the provisions of
* the GPL or the LGPL are applicable instead of those above. If you wish to
* allow use of your version of this file only under the terms of the either
* the GPL or LGPL and not to allow others to use your version of this file
* under the MPL, indicate your decision by deleting the provisions above
* and replace them with the notice and other provisions required by the GPL
* or LGPL. If you do not delete the provisions above, a recipient may use
* your version of this file under the terms of any one of the MPL, the GPL
* or the LGPL.
* ***** END LICENSE BLOCK ***** */

#ifndef _MOTION_COLOUR_ARROWS_H_
#define _MOTION_COLOUR_ARROWS_H_

#include <util/instrumentation/libdirac_instrument/motion_arrows.h>

namespace dirac_instr
{
    //! Class to carry out overlay of motion vectors as coloured arrows
    /*
        Sub-classes DrawMotionArrows
        Parent class carries out drawing of arrows, this class carries out
        representing motion vector size using colour
    */
    class DrawMotionColourArrows : public DrawMotionArrows
    {
    public :
        //! Constructor
        /*
            Calls DrawMotionArrows constructor
        */
        DrawMotionColourArrows(Frame &, DrawFrameMotionParams &, const MvArray &, int, int);
        
        //! Destructor
        ~DrawMotionColourArrows();

        ////////////////////////////////////////////////////////////
        //                                                        //
        //    Assumes default copy constructor and assignment =   //
        //                                                        //
        ////////////////////////////////////////////////////////////
            
        //! Calls DrawMotionArrows::DrawArrow() then colours blocks
        void DrawBlock(int, int);
        
        //! Draws power bar legend representing motion vector size
        void DrawLegend();
        
    private :

        //! Clip value for maximum motion vector size
        int m_mv_clip;
        
    };

} // namespace dirac_instr

#endif

==> dirac_0.10.0.orig.tar.gz: dirac-0.10.0/util/instrumentation/libdirac_instrument/motion_colour_arrows.h <==
/* ***** BEGIN LICENSE BLOCK *****
*
* $Id: motion_colour_arrows.h,v 1.3 2008/01/31 11:25:20 tjdwave Exp $ $Name: Dirac_0_10_0 $
*
* Version: MPL 1.1/GPL 2.0/LGPL 2.1
*
* The contents of this file are subject to the Mozilla Public License
* Version 1.1 (the "License"); you may not use this file except in compliance
* with the License. You may obtain a copy of the License at
* http://www.mozilla.org/MPL/
*
* Software distributed under the License is distributed on an "AS IS" basis,
* WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
* the specific language governing rights and limitations under the License.
*
* The Original Code is BBC Research and Development code.
*
* The Initial Developer of the Original Code is the British Broadcasting
* Corporation.
* Portions created by the Initial Developer are Copyright (C) 2004.
* All Rights Reserved.
*
* Contributor(s): Chris Bowley (Original Author)
*
* Alternatively, the contents of this file may be used under the terms of
* the GNU General Public License Version 2 (the "GPL"), or the GNU Lesser
* Public License Version 2.1 (the "LGPL"), in which case the provisions of
* the GPL or the LGPL are applicable instead of those above. If you wish to
* allow use of your version of this file only under the terms of the either
* the GPL or LGPL and not to allow others to use your version of this file
* under the MPL, indicate your decision by deleting the provisions above
* and replace them with the notice and other provisions required by the GPL
* or LGPL. If you do not delete the provisions above, a recipient may use
* your version of this file under the terms of any one of the MPL, the GPL
* or the LGPL.
* ***** END LICENSE BLOCK ***** */

#ifndef _MOTION_COLOUR_ARROWS_H_
#define _MOTION_COLOUR_ARROWS_H_

#include <util/instrumentation/libdirac_instrument/motion_arrows.h>

namespace dirac_instr
{
    //! Class to carry out overlay of motion vectors as coloured arrows
    /*
        Sub-classes DrawMotionArrows
        Parent class carries out drawing of arrows, this class carries out
        representing motion vector size using colour
    */
    class DrawMotionColourArrows : public DrawMotionArrows
    {
    public :
        //! Constructor
        /*
            Calls DrawMotionArrows constructor
        */
        DrawMotionColourArrows(Picture &, DrawPictureMotionParams &, const MvArray &, int, int);
        
        //! Destructor
        ~DrawMotionColourArrows();

        ////////////////////////////////////////////////////////////
        //                                                        //
        //    Assumes default copy constructor and assignment =   //
        //                                                        //
        ////////////////////////////////////////////////////////////
            
        //! Calls DrawMotionArrows::DrawArrow() then colours blocks
        void DrawBlock(int, int);
        
        //! Draws power bar legend representing motion vector size
        void DrawLegend();
        
    private :

        //! Clip value for maximum motion vector size
        int m_mv_clip;
        
    };

} // namespace dirac_instr

#endif
